@@ -28,6 +28,12 @@ sub brackets {
   return '[' . $t . ']';
 }
 
+sub plain {
+  my $self = shift;
+  my ($t) = @_;
+  return $t;
+}
+
 sub emph {
   my $self = shift;
   my ($t) = @_;
@@ -49,6 +55,11 @@ sub fullcaps {
   return uc($t);
 }
 
+sub url {
+  my ($t) = @_;
+  return $t;
+}
+
 sub singlequote {
   my ($t) = @_;
   return "'$t'";
@@ -69,6 +80,10 @@ sub nobreakspace {
   return ' ';
 }
 
+sub space {
+  return ' ';
+}
+
 sub language {
   my $self = shift;
   my ($lang, $t) = @_;
